==> Vega_1.0.0.zip: Vega/doc/Vega.R <==
###################################################
### chunk number 1: loadVega
###################################################
#line 50 "Vega.Rnw"
library(Vega)


###################################################
### chunk number 2: loadG519Data
###################################################
#line 55 "Vega.Rnw"
data(G519)


###################################################
### chunk number 3: printG519Data
###################################################
#line 69 "Vega.Rnw"
G519[1:16,]


###################################################
### chunk number 4: runVegaWithSexChromosomes
###################################################
#line 77 "Vega.Rnw"
seg <- vega(CNVdata=G519, chromosomes=c(1:22,"X","Y"))


###################################################
### chunk number 5: runVegaChromosomes_1_and_X
###################################################
#line 85 "Vega.Rnw"
seg_1X <- vega(CNVdata=G519, chromosomes=c(1,"X"))


###################################################
### chunk number 6: printResults
###################################################
#line 92 "Vega.Rnw"
seg[1:5,]


###################################################
### chunk number 7: plotAllChromosomes_LRR
###################################################
#line 122 "Vega.Rnw"
plotSegmentation(G519, seg, chromosomes=c(1:22,"X","Y"), opt=0)


###################################################
### chunk number 8: PlotChromosome1_LRR
###################################################
#line 130 "Vega.Rnw"
plotSegmentation(G519, seg, chromosomes=c(1), opt=0)


###################################################
### chunk number 9: PlotChromosome1_Label
###################################################
#line 138 "Vega.Rnw"
plotSegmentation(G519, seg, chromosomes=c(1), opt=1)

==> Vega_1.4.0.zip: Vega/doc/Vega.R <==
### R code from vignette source 'Vega.Rnw'

###################################################
### code chunk number 1: loadVega
###################################################
library(Vega)


###################################################
### code chunk number 2: loadG519Data
###################################################
data(G519)


###################################################
### code chunk number 3: printG519Data
###################################################
G519[1:16,]


###################################################
### code chunk number 4: runVegaWithSexChromosomes
###################################################
seg <- vega(CNVdata=G519, chromosomes=c(1:22,"X","Y"))


###################################################
### code chunk number 5: runVegaChromosomes_1_and_X
###################################################
seg_1X <- vega(CNVdata=G519, chromosomes=c(1,"X"))


###################################################
### code chunk number 6: printResults
###################################################
seg[1:5,]


###################################################
### code chunk number 7: plotAllChromosomes_LRR
###################################################
plotSegmentation(G519, seg, chromosomes=c(1:22,"X","Y"), opt=0)


###################################################
### code chunk number 8: PlotChromosome1_LRR
###################################################
plotSegmentation(G519, seg, chromosomes=c(1), opt=0)


###################################################
### code chunk number 9: PlotChromosome1_Label
###################################################
plotSegmentation(G519, seg, chromosomes=c(1), opt=1)
